tvb-storage
-----------

Part of TVB Distribution package.

Module used for Files Storage of TVB data.
Currently it has a H5 backend only, but future implementations are intended.
It contains files read&write mechanisms,
plus encryption mechanism (by default disabled for speed).

Install::

    pip install tvb-storage


API in module `tvb.storage.storage_interface`.